@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "diredfd" "2.0.3"
+(define-package "diredfd" "20241209.623"
   "Dired functions and settings to mimic FD/FDclone."
   '((emacs "28.1"))
   :url "https://github.com/knu/diredfd.el"
-  :commit "a3eb656d2bd201a193fdb1ac547c075717ee7561"
-  :revdesc "a3eb656d2bd2"
+  :commit "d789710c7e9699dae6ca87dcbfc27641a85fa3b6"
+  :revdesc "d789710c7e96"
   :keywords '("unix" "directories" "dired")
   :authors '(("Akinori MUSHA" . "knu@iDaemons.org"))
   :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
